::: typing_inspection.typing_objects
    options:
      show_labels: false
      group_by_category: false
      members:
        - is_annotated
        - is_any
        - is_classvar
        - is_concatenate
        - is_deprecated
        - is_final
        - is_generic
        - is_literal
        - is_literalstring
        - is_namedtuple
        - is_never
        - is_newtype
        - is_nodefault
        - is_noreturn
        - is_notrequired
        - is_paramspec
        - is_paramspecargs
        - is_paramspeckwargs
        - is_readonly
        - is_required
        - is_self
        - is_typealias
        - is_typealiastype
        - is_typeguard
        - is_typeis
        - is_typevar
        - is_typevartuple
        - is_union
        - is_unpack
        - DEPRECATED_ALIASES
